==> haskell-hashable-1.4.3.0-46.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable
version:              1.4.3.0
visibility:           public
id:                   hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
key:                  hashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Milan Straka <fox@ucw.cz>
    Johan Tibell <johan.tibell@gmail.com>

stability:            Provisional
homepage:             http://github.com/haskell-unordered-containers/hashable
synopsis:             A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.

    The '\''Hashable'\'' '\''hash'\'' values are not guaranteed to be stable across library versions, operating systems or architectures. For stable hashing use named hashes: SHA256, CRC32 etc.

category:             Data
abi:                  0864554cbbb1b04d7133b477ffb601f3
exposed:              True
exposed-modules:
    Data.Hashable Data.Hashable.Generic Data.Hashable.Lifted

hidden-modules:
    Data.Hashable.Class Data.Hashable.Generic.Instances
    Data.Hashable.Imports Data.Hashable.LowLevel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hashable-1.4.3.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hashable-1.4.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable
hs-libraries:         HShashable-1.4.3.0-BWGpbAVaWdFEBuRI2sTyFL
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    data-array-byte-0.1.0.1-LhjadnRSQr4LDU6AcGeTDD deepseq-1.4.6.1
    filepath-1.4.2.2 ghc-bignum-1.2 ghc-prim-0.8.0 text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html:         /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-1.4.4.0-6.2-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hashable
version:              1.4.4.0
visibility:           public
id:                   hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
key:                  hashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
license:              BSD-3-Clause
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Milan Straka <fox@ucw.cz>
    Johan Tibell <johan.tibell@gmail.com>

stability:            Provisional
homepage:             http://github.com/haskell-unordered-containers/hashable
synopsis:             A class for types that can be converted to a hash value
description:
    This package defines a class, '\''Hashable'\'', for types that
    can be converted to a hash value.  This class
    exists for the benefit of hashing-based data
    structures.  The package provides instances for
    basic types and a way to combine hash values.

    The '\''Hashable'\'' '\''hash'\'' values are not guaranteed to be stable across library versions, operating systems or architectures. For stable hashing use named hashes: SHA256, CRC32 etc.

category:             Data
abi:                  9f3a2319c975af8d2bce88dc6bcdbbb7
exposed:              True
exposed-modules:
    Data.Hashable Data.Hashable.Generic Data.Hashable.Lifted

hidden-modules:
    Data.Hashable.Class Data.Hashable.Generic.Instances
    Data.Hashable.Imports Data.Hashable.LowLevel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hashable-1.4.4.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hashable-1.4.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable
hs-libraries:         HShashable-1.4.4.0-KJ184tiZpE52U0PEHxyV1r
depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    data-array-byte-0.1.0.1-31kF3UWpQGYCpwbtQXGDZf deepseq-1.4.6.1
    filepath-1.4.2.2 ghc-bignum-1.2 ghc-prim-0.8.0
    os-string-2.0.6-dyLaG5nJtBLZ3AW2Hqd9g text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-hashable/html/hashable.haddock
haddock-html:         /usr/share/doc/haskell-hashable/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
